
.messagelist tr td.authres_status {
    width: 17px;
    padding: 0 0 0 3px;
}

.messagelist tr td.authres_status span {
    display: inline-block;
    vertical-align: middle;
    width: 14px;
    background: url(badge.png) center no-repeat;
}

.authres-status-img {
    vertical-align: top;
    height: 14px;
    width: 14px;
}

.widescreen .authres-status-img {
    position: relative;
    top: -1px;
    height: 12px;
    width: 12px;
}
