<?php

$labels = array();
$labels['nosignature'] = 'Липсва инфорормация за сигнатура';
$labels['noauthresults'] = 'Намерена е сигнатура, но липсва заглавие с резултати от удостоверяване на самоличност. Проблем с конфигурацията на сървъра?';
$labels['signaturepass'] = 'Валидна сигнатура от домейна на подателя. Проверено от';
$labels['partialpass'] = 'Съществуват невалидни сигнатури, но поне една е валидна от домейна на подателя. Проверено от';
$labels['thirdparty'] = 'Съществува сигнатура, коята е подписана от трета страна, но тя е за различен домейн от този на подателя. Проверено от';
$labels['temporaryinvalid'] = 'Сигнатурата е (временно) невалидна! Проверено от';
$labels['invalidsignature'] = 'Сигнатурата е невалидна! Проверено от';

$labels['for'] = 'за';
$labels['by'] = 'от';

$labels['section_title']  = 'Статус на удостоверяване на самоличност';
$labels['column_title']  = 'Резултат удостоверяване';

$labels['title_enable_column']  = 'Разрешаване на колона';
$labels['label_enable_column']  = 'Разрешаване на колона с резултат от удостоверяване на самоличност в списък с писма';
$labels['label_fallback_verifier'] = 'Използвай вградена проверка на DKIM (ако е намерена сигнатура без заглавие с резултати от удост. на самоличност)';

$labels['title_trusted_mtas'] = 'Надеждни МТА';
$labels['label_trusted_mtas'] = 'Разделени със запетая authserv-ID на доверени МТА. Ще бъдат показани само резултатите от тези MTA';

$labels['title_include_status'] = 'Показвай само следните статуси';
$labels['label_include_status1']  = 'Не е намерена сигнатура';
$labels['label_include_status2']  = 'Намерена е сигнатура но липсва заглавие с резултати от удост. на самоличност';
$labels['label_include_status4']  = 'Всички сигнатури са валидни';
$labels['label_include_status8']  = 'Поне една сигнатура е валидна';
$labels['label_include_status16']  = 'Сигнатура от трета страна';
$labels['label_include_status32']  = 'Сигнатурата е временно невалидна';
$labels['label_include_status64']  = 'Сигнатурата е перманентно невалидна';

?>
