<?php

$labels = array();
$labels['nosignature'] = 'Гарын үсгийн мэдээлэл олсонгүй';
$labels['noauthresults'] = 'Гарын үсэг олдсон ч толгой хэсэгт нэвтрэлтийн үр дүн  олдсонгүй. Серверийн тохиргооны асуудал?';
$labels['signaturepass'] = 'Илгээгчийн домэйн нэр зөв гарын үсэгтэй. Баталгаажуулсан: ';
$labels['partialpass'] = 'Илгээгчийн домэйний гарын үсгүүдээс нэг нь зөв, зарим нь буруу байна. Баталгаажуулсан: ';
$labels['thirdparty'] = 'Гуравдагч этгээд баталгаажуулсан, гарын үсэг байгаач өөр домэйн нэр нь өөр байна. Баталгаажуулсан: ';
$labels['temporaryinvalid'] = 'Гарын үсэг (түр) зөв биш байна! Шалгасан: ';
$labels['invalidsignature'] = 'Гарын үсэг буруу! шалгасан: ';

$labels['for'] = 'for';
$labels['by'] = 'аар';

$labels['section_title']  = 'Нэвтрэлтийн төлөв';
$labels['column_title']  = 'Нэвт. Үр дүн';

$labels['title_enable_column']  = 'Баганыг идэвхжүүлэх';
$labels['label_enable_column']  = 'Захианы жагсаалтанд нэвтрэлтийн дүр баганыг идэвхжүүлэх';
$labels['label_fallback_verifier'] = 'Дотоод DKIM шалгагч ашиглах (хэрэв гарын үсэг олдсон ч толгой хэсэгт нэвтрэлтийн үр дүн байхгүй) ';

$labels['title_trusted_mtas'] = 'Trusted mta\'s';
$labels['label_trusted_mtas'] = 'Comma separated authserv-id list of mta\'s you trust. Only results from these mta\'s will be shown';

$labels['title_include_status'] = 'Зөвхөн дараах төлөвүүдийг харуулна';
$labels['label_include_status1']  = 'Гарын үсэг олдсонгүй';
$labels['label_include_status2']  = 'Гарын үсэг олдсон ч толгой хэсэгт нэвтрэлтийн үр дүн олдоогүй';
$labels['label_include_status4']  = 'Бүх гарын үсэг зөв';
$labels['label_include_status8']  = 'Ядаж нэг гарын үсэг зөв';
$labels['label_include_status16']  = 'Гуравдагч этгээдийн гарын үсэг';
$labels['label_include_status32']  = 'Гарын үсэг түр алдаатай';
$labels['label_include_status64']  = 'Гарын үсэг алдаатай';

?>
