<?php

$labels = array();
$labels['nosignature'] = 'Gjin hântekening ynformaasje';
$labels['noauthresults'] = 'Hântekening fûn mar gjin autentikaasje risseltaten kop. Tsjinner konfiguraasje probleem?';
$labels['signaturepass'] = 'Jildige hântekening(en) fan stjoerder\'s domyn. Ferifiearre troch';
$labels['partialpass'] = 'Guon hantekenings binne ûnjildich mar op syn minst ien is jildich foar stjoerder\'s domein. Ferifiearre troch';
$labels['thirdparty'] = 'Ûndertekene troch tredde partij, hântekening is oanwêzich mar foar in oar domyn as út it adres. Ferifiearre foar';
$labels['temporaryinvalid'] = 'Hântekening is (tydlik) net jildich! Ferifiearre troch';
$labels['invalidsignature'] = 'Ûndertekening is net jildich! Ferifiearre troch';

$labels['for'] = 'foar';
$labels['by'] = 'troch';

$labels['section_title']  = 'Autentikaasje Status';
$labels['column_title']  = 'Autentikaasje Risseltaat';

$labels['title_enable_column']  = 'Kolom Ynskeakelje';
$labels['label_enable_column']  = 'Autentikaasje risseltaat kolom ynskeakelje yn berjocht lyst';
$labels['label_fallback_verifier'] = 'Brûk ynterne DKIM verifier (as hântekening fûn mar gjin autentikaasje risseltaten kop)';

$labels['title_trusted_mtas'] = 'Trusted mta\'s';
$labels['label_trusted_mtas'] = 'Comma separated authserv-id list of mta\'s you trust. Only results from these mta\'s will be shown';

$labels['title_include_status'] = 'Lit allinnich de folgjende status sjen';
$labels['label_include_status1']  = 'Gjin hântekening fûn';
$labels['label_include_status2']  = 'Hântekening fûn mar gjin autentikaasje risseltaten kop';
$labels['label_include_status4']  = 'Alle hântekenings passearje falidaasje';
$labels['label_include_status8']  = 'Op syn minst ien ûndertekening passearre falidaasje';
$labels['label_include_status16']  = 'Tredde partij hântekening';
$labels['label_include_status32']  = 'Hantekening tydlik mislearre';
$labels['label_include_status64']  = 'Hantekening permanint mislearre';

?>
