<?php

$labels = array();
$labels['nosignature'] = 'Titour ebet war ar sinadur';
$labels['noauthresults'] = 'Kavet ez eus bet ar sinadur met ket talbenn an disoc\'hoù naoudi. Ur gudenn \'zo gant kefluniadur an dafariad?';
$labels['signaturepass'] = 'Sinadur(ioù) talvoudek a-berzh domani ar c\'haser. gwiriet gant';
$labels['partialpass'] = 'Ul lodenn eus ar sinadurioù a zo didalvoudek met unan d\'an nebeutañ a zo talvoudek evit domani ar c\'haser. Gwiriet gant';
$labels['thirdparty'] = 'Sinet gant un trede, aze emañ ar sinadur met evit un domani disheñvhel eus hini ar chomlec\'h. Gwiriet gant';
$labels['temporaryinvalid'] = 'Didalvoudek (evit ur mare) eo ar sinadur! Gwiriet gant';
$labels['invalidsignature'] = 'Didalvoudek eo ar sinadur! Gwiriet gant';

$labels['for'] = 'evit';
$labels['by'] = 'gant';

$labels['section_title']  = 'Stad an naoudi';
$labels['column_title']  = 'Disoc\'hoù an naoudi';

$labels['title_enable_column']  = 'Gweredekaat ar bann';
$labels['label_enable_column']  = 'Gweredekaat ar bann disoc\'hoù naoudi e roll ar c\'hemennadennoù';
$labels['label_fallback_verifier'] = 'Ober gant ar gwirier DKIM diabarzh (m\'eo bet kavet ar sinadur met ket an talbenn disoc\'hoù naoudi)';

$labels['title_trusted_mtas'] = 'Trusted mta\'s';
$labels['label_trusted_mtas'] = 'Comma separated authserv-id list of mta\'s you trust. Only results from these mta\'s will be shown';

$labels['title_include_status'] = 'Diskouez ar stadoù da-heul nemetken';
$labels['label_include_status1']  = 'Sinadur ebet kavet';
$labels['label_include_status2']  = 'Kavet ez eus bet ar sinadur met ket talbenn an disoc\'hoù naoudi';
$labels['label_include_status4']  = 'Tremenet eo ar gwiriañ gant an holl sinadurioù';
$labels['label_include_status8']  = 'Ur sinadur d\'an nebeutañ en deus tremenet ar gwiriañ';
$labels['label_include_status16']  = 'Sinadur un trede';
$labels['label_include_status32']  = 'C\'hwitadenn padennek ar sinadur';
$labels['label_include_status64']  = 'C\'hwitadenn badel ar sinadur';

?>
